pub enum ApiResponse<T> {
Valid(T),
Invalid(InvalidApiResponseError),
}Expand description
A json response from the UserData API.
Variants
Implementations
Sourceimpl<T> ApiResponse<T>
impl<T> ApiResponse<T>
Sourcepub fn into_result(self) -> Result<T, InvalidApiResponseError>
pub fn into_result(self) -> Result<T, InvalidApiResponseError>
Convert this into as Result.
Sourcepub fn take_valid(self) -> Option<T>
pub fn take_valid(self) -> Option<T>
Consume self and return the valid variant, or None.
Sourcepub fn take_invalid(self) -> Option<InvalidApiResponseError>
pub fn take_invalid(self) -> Option<InvalidApiResponseError>
Consume self and return the invalid variant, or None.